# `AIgarMIC`

## Introduction

`AIgarMIC` is a Python package and collection of commandline scripts designed to facilitate the automation of agar dilution minimum inhibitory concentration image interpretation.

`AIgarMIC` has the following features:

* Automated image processing of agar dilution plates in the following format (note the use of an anchoring black grid to delineate colonies): 

![Example image 1](/readme_images/2.0.jpg)

* Flexible MIC calculation algorithm with ability to disregard inhibited growth
* Quality assurance metrics to ensure MIC predictions
* Pre-trained models and example datasets
* Scripts to support custom model training

## Documentation

The full documentation for `AIgarMIC` can be found at:

https://aigarmic.readthedocs.io/en/latest/

## Installation

To install `AIgarMIC`, follow the instructions below:

https://aigarmic.readthedocs.io/en/latest/installation.html

## Usage

To use `AIgarMIC`, follow one of the typical workflows described below:

https://aigarmic.readthedocs.io/en/latest/introduction.html#typical-workflows

## Author information

The lead developer of ``AIgarMIC`` is Alessandro Gerada (https://github.com/agerada/ and https://agerada.github.io/), 
University of Liverpool, UK (alessandro.gerada@liverpool.ac.uk).

## External links

The manuscript describing the validation of `AIgarMIC` can be found at: https://doi.org/10.1128/spectrum.04209-23.
Optional asset data is available at: https://10.17638/datacat.liverpool.ac.uk/2631.

## License

`AIgarMIC` is provided under the GNU General Public License v3.0. For more information, see the LICENSE file.
